@@ -40,8 +40,8 @@ Returns a page from templates and documents provided by the Bryar object.
 sub _tt {
     my ($class, $bryar) = @_;
     my @path = $bryar->{config}->datadir;
-    unshift @path, $bryar->{config}->datadir."/".$bryar->{config}->{arguments}->{subblog} 
-        if exists $bryar->{config}->{arguments}->{subblog};
+    unshift @path, $bryar->{config}->datadir."/".$bryar->{arguments}->{subblog} 
+        if exists $bryar->{arguments}->{subblog};
         
     @path = map { $_, $_."/templates" } @path;
     return Template->new({
@@ -89,25 +89,11 @@ sub register_format {
     $formats{$format} = [$filename, $content_type];
 }
 
-# display formats
 __PACKAGE__->register_format( html => "template.html", "text/html" );
-
-# TODO: put formats in a formats/ folder by default, but add a config option
-# for their location.
-
-# syndication formats (full posts)
-__PACKAGE__->register_format( atom => "template.atom", "application/atom+xml" ); # "application/atom+xml" );
-__PACKAGE__->register_format( xml  => "template.rss",  "application/rdf+xml");
-__PACKAGE__->register_format( rss  => "template.rss",  "application/rdf+xml");
-__PACKAGE__->register_format( rdf  => "template.rss",  "application/rdf+xml");
-__PACKAGE__->register_format( rss2 => "template.rss2", "application/rss+xml");
-
-# syndication formats (excerpted posts)
-__PACKAGE__->register_format( atomexcerpt => "template.atomexcerpt", "application/atom+xml" );
-__PACKAGE__->register_format( xmlexcerpt  => "template.rssexcerpt", "application/rdf+xml");
-__PACKAGE__->register_format( rssexcerpt  => "template.rssexcerpt", "application/rdf+xml");
-__PACKAGE__->register_format( rdfexcerpt  => "template.rssexcerpt", "application/rdf+xml");
-__PACKAGE__->register_format( rss2excerpt => "template.rss2excerpt", "application/rss+xml");
+__PACKAGE__->register_format( atom => "template.atom", "text/xml" );
+__PACKAGE__->register_format( xml  => "template.rss",  "text/xml" );
+__PACKAGE__->register_format( rss  => "template.rss",  "text/xml" );
+__PACKAGE__->register_format( rdf  => "template.rss",  "text/xml" );
 
 sub generate {
     my $class = shift;
@@ -120,17 +106,24 @@ sub generate {
     return ($ct, $class->_tt_process($file, @_));
 }
 
+
+
+
 =head1 LICENSE
 
 This module is free software, and may be distributed under the same
 terms as Perl itself.
 
+
 =head1 AUTHOR
 
 Copyright (C) 2003, Simon Cozens C<simon@kasei.com>
 
+
 =head1 SEE ALSO
 
-=cut
+
+
+
 
 1;
